@@ -55,15 +55,15 @@ class EnviarPedido(Enviar):
         nome = self.pedido.cliente.nome
         if nome:
             nome = nome.strip()
-        if len(nome.split(" ")) < 2:
-            nome = u"{} x".format(nome)
+        if len(self.pedido.cliente.nome.split(" ")) < 2:
+            nome = u"{} x".format(self.pedido.cliente.nome)
         if "&" in nome or "?" in nome:
             nome = nome.replace("&", "E")
         if "?" in nome:
             nome = nome.replace("?", " ")
         return self.formatador.trata_unicode_com_limite(nome, limite=50, ascii=True, trata_espaco_duplo=True)
 
-    def gerar_dados_de_envio(self):
+    def gerar_dados_de_envio(self, passo=None):
         notification_url = PAGSEGURO_PREFERENCE_NOTIFICATION_URL.format(self.pedido.conta_id)
         parametros = ParametrosPagSeguro(conta_id=self.pedido.conta_id, usa_alt=(self.configuracao_pagamento.aplicacao == 'pagseguro-alternativo'))
         numero_telefone = self.telefone
@@ -111,10 +111,8 @@ class EnviarPedido(Enviar):
         return None
 
     def processar_resposta(self, resposta):
-        if resposta.status_code in (401, 403) or 'forbiden' in resposta.content.lower():
+        if resposta.status_code == 401:
             return {"content": {"mensagem": u"Autorização da plataforma falhou em {}".format(self.url)}, "status": resposta.status_code, "reenviar": False}
-        if resposta.status_code == 500 or 'internal server error' in resposta.content.lower():
-            return {"content": {"mensagem": u"O sistema do PagSeguro está indisponível no momento"}, "status": resposta.status_code, "reenviar": False}
         retorno = self.formatador.xml_para_dict(resposta.content)
         if resposta.status_code in (201, 200):
             url = "https://{}pagseguro.uol.com.br/v2/checkout/payment.html?code={}".format(self.sandbox, retorno["checkout"]["code"])
